@@ -1,3 +1,12 @@
+
+#  FoXPath, tools for processing FoXPath test suites,
+#  by Martin Keegan, Mark Brough and Ben Webb
+
+#  Copyright (C) 2013  Ben Webb
+#
+#  This programme is free software; you may redistribute and/or modify
+#  it under the terms of the GNU Affero General Public License v3.0
+
 import re
 from functools import partial
 
@@ -78,8 +87,4 @@ def generate_mappings():
     def exist(activity, groups):
         return exist_check(activity, groups[0]) 
 
-    @add('(.*)')
-    def fail(line):
-        return None
-
     return mappings
